sequencetools.CyclicTree
========================

.. inheritance-diagram:: abjad.tools.sequencetools.CyclicTree.CyclicTree.CyclicTree
   :private-bases:

.. autoclass:: abjad.tools.sequencetools.CyclicTree.CyclicTree.CyclicTree

Read-only Properties
--------------------

.. autoattribute:: abjad.tools.sequencetools.CyclicTree.CyclicTree.CyclicTree.children

   .. note:: Inherited from :py:class:`sequencetools.Tree <abjad.tools.sequencetools.Tree.Tree.Tree>`

.. autoattribute:: abjad.tools.sequencetools.CyclicTree.CyclicTree.CyclicTree.depth

   .. note:: Inherited from :py:class:`sequencetools.Tree <abjad.tools.sequencetools.Tree.Tree.Tree>`

.. autoattribute:: abjad.tools.sequencetools.CyclicTree.CyclicTree.CyclicTree.improper_parentage

   .. note:: Inherited from :py:class:`sequencetools.Tree <abjad.tools.sequencetools.Tree.Tree.Tree>`

.. autoattribute:: abjad.tools.sequencetools.CyclicTree.CyclicTree.CyclicTree.index_in_parent

   .. note:: Inherited from :py:class:`sequencetools.Tree <abjad.tools.sequencetools.Tree.Tree.Tree>`

.. autoattribute:: abjad.tools.sequencetools.CyclicTree.CyclicTree.CyclicTree.level

   .. note:: Inherited from :py:class:`sequencetools.Tree <abjad.tools.sequencetools.Tree.Tree.Tree>`

.. autoattribute:: abjad.tools.sequencetools.CyclicTree.CyclicTree.CyclicTree.negative_level

   .. note:: Inherited from :py:class:`sequencetools.Tree <abjad.tools.sequencetools.Tree.Tree.Tree>`

.. autoattribute:: abjad.tools.sequencetools.CyclicTree.CyclicTree.CyclicTree.position

   .. note:: Inherited from :py:class:`sequencetools.Tree <abjad.tools.sequencetools.Tree.Tree.Tree>`

.. autoattribute:: abjad.tools.sequencetools.CyclicTree.CyclicTree.CyclicTree.proper_parentage

   .. note:: Inherited from :py:class:`sequencetools.Tree <abjad.tools.sequencetools.Tree.Tree.Tree>`

.. autoattribute:: abjad.tools.sequencetools.CyclicTree.CyclicTree.CyclicTree.root

   .. note:: Inherited from :py:class:`sequencetools.Tree <abjad.tools.sequencetools.Tree.Tree.Tree>`

.. autoattribute:: abjad.tools.sequencetools.CyclicTree.CyclicTree.CyclicTree.width

   .. note:: Inherited from :py:class:`sequencetools.Tree <abjad.tools.sequencetools.Tree.Tree.Tree>`

Methods
-------

.. automethod:: abjad.tools.sequencetools.CyclicTree.CyclicTree.CyclicTree.get_next_n_complete_nodes_at_level

   .. note:: Inherited from :py:class:`sequencetools.Tree <abjad.tools.sequencetools.Tree.Tree.Tree>`

.. automethod:: abjad.tools.sequencetools.CyclicTree.CyclicTree.CyclicTree.get_next_n_nodes_at_level

   .. note:: Inherited from :py:class:`sequencetools.Tree <abjad.tools.sequencetools.Tree.Tree.Tree>`

.. automethod:: abjad.tools.sequencetools.CyclicTree.CyclicTree.CyclicTree.get_node_at_position

   .. note:: Inherited from :py:class:`sequencetools.Tree <abjad.tools.sequencetools.Tree.Tree.Tree>`

.. automethod:: abjad.tools.sequencetools.CyclicTree.CyclicTree.CyclicTree.get_position_of_descendant

   .. note:: Inherited from :py:class:`sequencetools.Tree <abjad.tools.sequencetools.Tree.Tree.Tree>`

.. automethod:: abjad.tools.sequencetools.CyclicTree.CyclicTree.CyclicTree.is_at_level

   .. note:: Inherited from :py:class:`sequencetools.Tree <abjad.tools.sequencetools.Tree.Tree.Tree>`

.. automethod:: abjad.tools.sequencetools.CyclicTree.CyclicTree.CyclicTree.iterate_at_level

   .. note:: Inherited from :py:class:`sequencetools.Tree <abjad.tools.sequencetools.Tree.Tree.Tree>`

.. automethod:: abjad.tools.sequencetools.CyclicTree.CyclicTree.CyclicTree.iterate_depth_first

   .. note:: Inherited from :py:class:`sequencetools.Tree <abjad.tools.sequencetools.Tree.Tree.Tree>`

.. automethod:: abjad.tools.sequencetools.CyclicTree.CyclicTree.CyclicTree.iterate_payload

   .. note:: Inherited from :py:class:`sequencetools.Tree <abjad.tools.sequencetools.Tree.Tree.Tree>`

.. automethod:: abjad.tools.sequencetools.CyclicTree.CyclicTree.CyclicTree.remove

   .. note:: Inherited from :py:class:`sequencetools.Tree <abjad.tools.sequencetools.Tree.Tree.Tree>`

.. automethod:: abjad.tools.sequencetools.CyclicTree.CyclicTree.CyclicTree.remove_to_root

   .. note:: Inherited from :py:class:`sequencetools.Tree <abjad.tools.sequencetools.Tree.Tree.Tree>`

.. automethod:: abjad.tools.sequencetools.CyclicTree.CyclicTree.CyclicTree.to_nested_lists

   .. note:: Inherited from :py:class:`sequencetools.Tree <abjad.tools.sequencetools.Tree.Tree.Tree>`

Special Methods
---------------

.. automethod:: abjad.tools.sequencetools.CyclicTree.CyclicTree.CyclicTree.__contains__

   .. note:: Inherited from :py:class:`sequencetools.Tree <abjad.tools.sequencetools.Tree.Tree.Tree>`

.. automethod:: abjad.tools.sequencetools.CyclicTree.CyclicTree.CyclicTree.__delattr__

   .. note:: Inherited from `__builtin__.object`

.. automethod:: abjad.tools.sequencetools.CyclicTree.CyclicTree.CyclicTree.__eq__

   .. note:: Inherited from :py:class:`sequencetools.Tree <abjad.tools.sequencetools.Tree.Tree.Tree>`

.. automethod:: abjad.tools.sequencetools.CyclicTree.CyclicTree.CyclicTree.__ge__

   .. note:: Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.sequencetools.CyclicTree.CyclicTree.CyclicTree.__getitem__

   .. note:: Inherited from :py:class:`sequencetools.Tree <abjad.tools.sequencetools.Tree.Tree.Tree>`

.. automethod:: abjad.tools.sequencetools.CyclicTree.CyclicTree.CyclicTree.__gt__

   .. note:: Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.sequencetools.CyclicTree.CyclicTree.CyclicTree.__hash__

   .. note:: Inherited from `__builtin__.object`

.. automethod:: abjad.tools.sequencetools.CyclicTree.CyclicTree.CyclicTree.__iter__

.. automethod:: abjad.tools.sequencetools.CyclicTree.CyclicTree.CyclicTree.__le__

   .. note:: Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.sequencetools.CyclicTree.CyclicTree.CyclicTree.__len__

   .. note:: Inherited from :py:class:`sequencetools.Tree <abjad.tools.sequencetools.Tree.Tree.Tree>`

.. automethod:: abjad.tools.sequencetools.CyclicTree.CyclicTree.CyclicTree.__lt__

   .. note:: Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.sequencetools.CyclicTree.CyclicTree.CyclicTree.__ne__

   .. note:: Inherited from :py:class:`sequencetools.Tree <abjad.tools.sequencetools.Tree.Tree.Tree>`

.. automethod:: abjad.tools.sequencetools.CyclicTree.CyclicTree.CyclicTree.__repr__

   .. note:: Inherited from :py:class:`sequencetools.Tree <abjad.tools.sequencetools.Tree.Tree.Tree>`

.. automethod:: abjad.tools.sequencetools.CyclicTree.CyclicTree.CyclicTree.__setattr__

   .. note:: Inherited from `__builtin__.object`

.. automethod:: abjad.tools.sequencetools.CyclicTree.CyclicTree.CyclicTree.__str__

   .. note:: Inherited from :py:class:`sequencetools.Tree <abjad.tools.sequencetools.Tree.Tree.Tree>`
